@@ -3,7 +3,6 @@ from __future__ import print_function
 from itertools import chain
 from reprlib import recursive_repr
 
-iterchain = chain.from_iterable
 recursive = recursive_repr(fillvalue="…")
 
 from clu.constants import consts
@@ -30,10 +29,13 @@ INSTANCE_DELIMITER = '@'
 @recursive
 def strfield(value):
     """ Basic, simple, straightforward type-switch-based sub-repr """
-    from clu.typespace.namespace import nsrepr, isnamespace
+    from clu.typespace.namespace import nsshortrepr, isnamespace
+    from clu.dicts import cmshortrepr, ischainmap
     T = type(value)
     if isnamespace(T):
-        return nsrepr(value)
+        return nsshortrepr(value)
+    elif ischainmap(T):
+        return cmshortrepr(value)
     elif isstring(T):
         return f"“{value}”"
     elif issingleton(T):
